/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-20 17:15:49
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-11-29
 * @Description:
 *
 */
import type { ResponseInfo } from '@/types/res'
import type { TablePaginationSetting } from '@/types/table'

import { initLoadResource } from '@/utils/resource'
import { reactive } from 'vue'

import axiosInstance from '../utils/axios/axiosInstance'

// 资源的加载路径
const resourceInfo: Record<string, string> = {
  defaultHead: `/img/default/defaultHead.png`
}

// 使用blob的资源路径信息
const blobUrlInfo = reactive<Record<string, string>>({})

// 初始化资源
initLoadResource(resourceInfo).then((data) => {
  Object.assign(blobUrlInfo, data)
})

export function useTable(tableData: Array<any>, paginationSetting: TablePaginationSetting) {
  /**
   * @description: 设置默认头像
   * @param {Array} data 请求回来的数据表格
   * @return {Array<any>} 返回处理后的数据
   */
  const setDefaultHead = (data: Array<any>): Array<any> => {
    if (data) {
      data.map(async (item: any) => {
        if (!item.head) item.head = blobUrlInfo.defaultHead
      })
    }
    return data
  }

  /**
   * 将请求的数据写入tableData
   *
   * 对开启分页的数据做单独的处理
   *
   * @param dataList 数据列表
   * @param total 数据总量
   * @param openPagination 是否开启了分页查询
   * @return 成功返回true，反之false
   */
  const setTableData = (dataList: Array<any>, total: number, openPagination: boolean): boolean => {
    try {
      if (!dataList || dataList.length === 0) {
        tableData.length = 0
        paginationSetting.total = 0
      } else {
        paginationSetting.total = total
        dataList = setDefaultHead(dataList)

        // 如果开启了分页，设置 tableData 为二维数组，否则为一维数组
        const pageIndex = paginationSetting.currentPage ?? 0
        if (openPagination) {
          tableData[pageIndex] = dataList
        } else {
          tableData.splice(0, tableData.length, ...dataList)
        }
      }
      return true
    } catch (err) {
      console.error('数据处理错误:', err)
      return false
    }
  }

  /**
   * @description 获取表格数据
   * @param url 请求地址
   * @param option 请求参数
   * @return [表格数据，总数]
   */
  const getTableData = async (
    url: string,
    option: Record<string, any>
  ): Promise<[Array<any>, number]> => {
    try {
      const result = await axiosInstance.post<any, ResponseInfo>(url, option)
      console.log(result)
      return [result.data ?? [], result.count ?? 0]
    } catch (err) {
      console.error('请求数据错误:', err)
      return [[], 0]
    }
  }

  // const getTableData = async (
  //   url: string,
  //   option: Record<string, any>,
  //   isPagination: boolean = false
  // ): Promise<boolean> => {
  //   try {
  //     const result = await axiosInstance.post<any, ResponseInfo>(url, option)
  //     let data = result.data
  //
  //     // 没有数据则直接置为空
  //     if (!data) {
  //       tableData.length = 0
  //       paginationSetting.total = 0
  //     } else {
  //       paginationSetting.total = result.count ?? data.length
  //       data = setDefaultHead(data)
  //
  //       // 如果开启了分页，设置 tableData 为二维数组，否则为一维数组
  //       const pageIndex = paginationSetting.currentPage ?? 0
  //       if (isPagination) {
  //         tableData[pageIndex] = data
  //       } else {
  //         tableData.splice(0, tableData.length, ...data)
  //       }
  //     }
  //
  //     return true // 返回操作成功
  //   } catch (err) {
  //     console.error('网络请求错误:', err)
  //     throw err // 抛出错误让调用者处理
  //   }
  // }

  return {
    getTableData,
    setTableData
  }
}
